Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(13)

Unified Diff: include/core/SkRefCnt.h

Issue 19808007: Split atomic and mutex implementations and make inlinable. (Closed) Base URL: http://skia.googlecode.com/svn/trunk/
Patch Set: Include all the files. Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: include/core/SkRefCnt.h
===================================================================
--- include/core/SkRefCnt.h (revision 10251)
+++ include/core/SkRefCnt.h (working copy)
@@ -50,7 +50,7 @@
bool unique() const {
bool const unique = (1 == fRefCnt);
if (unique) {
// Aquire barrier (L/SL), if not provided by load of fRefCnt.
// Prevents user's 'unique' code from happening before decrements.
//TODO: issue the barrier.
}
@@ -72,9 +72,9 @@
SkASSERT(fRefCnt > 0);
// Release barrier (SL/S), if not provided below.
if (sk_atomic_dec(&fRefCnt) == 1) {
// Aquire barrier (L/SL), if not provided above.
// Prevents code in dispose from happening before the decrement.
- sk_membar_aquire__after_atomic_dec();
+ sk_membar_acquire__after_atomic_dec();
internal_dispose();
}
}
@@ -50,7 +50,7 @@
bool const unique = (1 == fRefCnt);
if (unique) {
- // Aquire barrier (L/SL), if not provided by load of fRefCnt.
+ // Acquire barrier (L/SL), if not provided by load of fRefCnt.
// Prevents user's 'unique' code from happening before decrements.
//TODO: issue the barrier.
@@ -72,9 +72,9 @@
// Release barrier (SL/S), if not provided below.
if (sk_atomic_dec(&fRefCnt) == 1) {
- // Aquire barrier (L/SL), if not provided above.
+ // Acquire barrier (L/SL), if not provided above.
// Prevents code in dispose from happening before the decrement.

Powered by Google App Engine
This is Rietveld 408576698